@@ -1,5 +1,5 @@
 import datetime
-from . import config
+from .. import config
 
 def prettify_list(data):
     """ returns list as pretty sting """
